==> qtcreator-plugin-cmake_3.0.1+14.04.20140415.orig.tar.gz: qtcreator-plugin-cmake-3.0.1+14.04.20140415/src/cmakeprojectmanager/cmakesettingspage.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CMAKEPROJECTMANAGER_INTERNAL_CMAKESETTINGSPAGE_H
#define CMAKEPROJECTMANAGER_INTERNAL_CMAKESETTINGSPAGE_H

#include <coreplugin/dialogs/ioptionspage.h>
#include <texteditor/codeassist/keywordscompletionassist.h>
#include <utils/pathchooser.h>
#include <QCheckBox>

namespace CMakeProjectManager {
namespace Internal {

class CMakeSettingsPage : public Core::IOptionsPage
{
    Q_OBJECT

public:
    CMakeSettingsPage();
    ~CMakeSettingsPage();

    QWidget *createPage(QWidget *parent);
    void apply();
    void finish();

    bool isCMakeExecutableValid() const;
    bool hasCodeBlocksMsvcGenerator() const;
    bool hasCodeBlocksNinjaGenerator() const;
    bool preferNinja() const;

    TextEditor::Keywords keywords();

private:
    void saveSettings() const;
    QString findCmakeExecutable() const;

    Utils::PathChooser *m_pathchooser;
    QCheckBox *m_preferNinja;
};

} // namespace Internal
} // namespace CMakeProjectManager

#endif // CMAKEPROJECTMANAGER_INTERNAL_CMAKESETTINGSPAGE_H

==> qtcreator-plugin-cmake_3.1.1+14.10.20140908.orig.tar.gz: qtcreator-plugin-cmake-3.1.1+14.10.20140908/src/cmakeprojectmanager/cmakesettingspage.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CMAKEPROJECTMANAGER_INTERNAL_CMAKESETTINGSPAGE_H
#define CMAKEPROJECTMANAGER_INTERNAL_CMAKESETTINGSPAGE_H

#include <coreplugin/dialogs/ioptionspage.h>
#include <texteditor/codeassist/keywordscompletionassist.h>
#include <utils/pathchooser.h>
#include <QCheckBox>
#include <QPointer>

namespace CMakeProjectManager {
namespace Internal {

class CMakeSettingsPage : public Core::IOptionsPage
{
    Q_OBJECT

public:
    CMakeSettingsPage();
    ~CMakeSettingsPage();

    QWidget *widget();
    void apply();
    void finish();

    bool isCMakeExecutableValid() const;
    bool hasCodeBlocksMsvcGenerator() const;
    bool hasCodeBlocksNinjaGenerator() const;
    bool preferNinja() const;

    TextEditor::Keywords keywords();

private:
    void saveSettings() const;
    QString findCmakeExecutable() const;

    QPointer<QWidget> m_widget;
    Utils::PathChooser *m_pathchooser;
    QCheckBox *m_preferNinja;
};

} // namespace Internal
} // namespace CMakeProjectManager

#endif // CMAKEPROJECTMANAGER_INTERNAL_CMAKESETTINGSPAGE_H
